==> uke-admin-web-scaffold-1.2.0-rc8.tgz: package/fe-deploy/create-project.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
import React from 'react';
import PropTypes from 'prop-types';
import { Loading, FormLayout, Tabs, Tab, TipPanel, Steps, GlobalPopover, Radio } from 'ukelli-ui';
import { Call } from 'basic-helper';
import CreateAsset from './create-asset';
import AssetsManager from './assets-manager';
import { createProject, getSShConfig } from './apis';
import wrapProjectFormOptions from './project-form';
import ActionAgent from "../action-agent";
var CreateProject = /** @class */ (function (_super) {
    __extends(CreateProject, _super);
    function CreateProject(props) {
        var _this = _super.call(this, props) || this;
        _this.state = __assign(__assign({}, _this.state), { activeIdx: 0, querying: true, createdProj: {} });
        _this.onCreateProj = function (formValue, actingRef) { return __awaiter(_this, void 0, void 0, function () {
            var _a, notify, onCreatedProject, agentOptions;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        _a = this.props, notify = _a.notify, onCreatedProject = _a.onCreatedProject;
                        agentOptions = {
                            actingRef: actingRef,
                            after: function (res) {
                                var err = res.err;
                                if (!err) {
                                    Call(onCreatedProject);
                                }
                                else {
                                    notify('创建项目', false, err);
                                }
                                return err ? {} : {
                                    activeIdx: 1,
                                    createdProj: res.data || {}
                                };
                            }
                        };
                        return [4 /*yield*/, this.reqAgent(createProject, agentOptions)(formValue)];
                    case 1:
                        _b.sent();
                        return [2 /*return*/];
                }
            });
        }); };
        _this.formBtns = [
            {
                action: function (formRef, actingRef) {
                    var checkRes = formRef.checkForm();
                    if (checkRes.isPass)
                        _this.onCreateProj(formRef.value, actingRef);
                },
                actingRef: 'creating',
                text: '新增',
            }
        ];
        return _this;
    }
    CreateProject.prototype.componentDidMount = function () {
        this.initData();
    };
    CreateProject.prototype.initData = function () {
        return __awaiter(this, void 0, void 0, function () {
            var _a, hostConfigRes;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        _a = this;
                        return [4 /*yield*/, wrapProjectFormOptions()];
                    case 1:
                        _a.formOptions = _b.sent();
                        return [4 /*yield*/, getSShConfig()];
                    case 2:
                        hostConfigRes = ((_b.sent()) || {}).data;
                        // let hostConfigData = {};
                        // hostConfigRes.forEach(item => hostConfigData[item.sshHost] = item);
                        this.setState({
                            sshConfig: hostConfigRes,
                            querying: false
                        });
                        return [2 /*return*/];
                }
            });
        });
    };
    // async getSSHConfig() {
    //   let hostConfigRes = await getSShConfig();
    //   // console.log(hostConfigRes)
    // }
    CreateProject.prototype.onCreatedAsset = function (assetData) {
        this.setState({
            activeIdx: 2,
            prevAssetData: assetData
        });
    };
    CreateProject.prototype.render = function () {
        var _this = this;
        var _a = this.state, activeIdx = _a.activeIdx, createdProj = _a.createdProj, querying = _a.querying, sshConfig = _a.sshConfig;
        return (React.createElement("div", null,
            React.createElement(TipPanel, { title: "\u4F7F\u7528\u8BF4\u660E", texts: [
                    '新建项目，只需要填写项目名称',
                    'web hook 是项目资源发布成功后触发的，与 GitHub 的 web hook 类似，用于回调通知',
                ] }),
            React.createElement(Loading, { loading: querying },
                React.createElement("div", null,
                    React.createElement(Steps, { activeIdx: activeIdx, className: "p10" },
                        React.createElement(Steps.Step, { title: "\u521B\u5EFA\u9879\u76EE" }),
                        React.createElement(Steps.Step, { title: "\u4E0A\u4F20\u8D44\u6E90\u6587\u4EF6" }),
                        React.createElement(Steps.Step, { title: "\u8D44\u6E90\u7BA1\u7406" })),
                    React.createElement(Tabs, { activeTabIdx: activeIdx },
                        React.createElement(Tab, { label: "\u521B\u5EFA\u9879\u76EE" },
                            React.createElement(FormLayout, { formOptions: this.formOptions, ref: function (e) {
                                    if (!e)
                                        return;
                                    _this.formRef = e.formHelper;
                                }, onChange: function (values, ref, val) {
                                    var targetDOM = '';
                                    if (ref !== 'scpTargetHost')
                                        return;
                                    try {
                                        targetDOM = _this.formRef._refs.scpTargetDir.iconInput;
                                    }
                                    catch (e) {
                                        console.log(e);
                                    }
                                    var targetValues = __spreadArrays(sshConfig).filter(function (item) { return item.sshHost === val; });
                                    var ideaTip = {};
                                    for (var _i = 0, targetValues_1 = targetValues; _i < targetValues_1.length; _i++) {
                                        var item = targetValues_1[_i];
                                        ideaTip[item.deployPath] = item.desc + "~" + item.deployPath;
                                    }
                                    var hasIdea = targetValues.length > 0;
                                    if (hasIdea) {
                                        GlobalPopover.show({
                                            elem: targetDOM,
                                            props: {
                                                style: {
                                                    zIndex: 1111,
                                                    width: 400,
                                                }
                                            },
                                            children: (React.createElement("div", { className: "p10" },
                                                React.createElement("h4", null, "\u90E8\u7F72\u8DEF\u5F84\u5EFA\u8BAE"),
                                                React.createElement("div", { className: "p10" },
                                                    React.createElement(Radio, { values: ideaTip, onChange: function (val) { return _this.selectedDeploy = val; } })),
                                                React.createElement("span", { className: "btn theme", onClick: function (e) {
                                                        GlobalPopover.close();
                                                        _this.formRef.changeValues({
                                                            scpTargetDir: _this.selectedDeploy
                                                        });
                                                    } }, "\u786E\u5B9A")))
                                        });
                                    }
                                    // let targetPath = '';
                                    // if(sshConfig[val]) {
                                    //   targetPath = sshConfig[val].deployPath || '';
                                    // }
                                    // this.formRef.changeValues({
                                    //   scpTargetDir: targetPath
                                    // });
                                }, formBtns: this.formBtns })),
                        React.createElement(Tab, { label: "\u4E0A\u4F20\u8D44\u6E90\u6587\u4EF6" },
                            React.createElement(CreateAsset, __assign({}, this.props, { projId: createdProj.id, onSuccess: function (assetData) { return _this.onCreatedAsset(assetData); } }))),
                        React.createElement(Tab, { label: "\u8D44\u6E90\u7BA1\u7406" },
                            React.createElement(AssetsManager, __assign({ releasable: true, getProject: function (e) { return createdProj; } }, this.props, { projId: createdProj.id })))),
                    React.createElement("hr", null),
                    React.createElement("div", { className: "p10 text-center" },
                        React.createElement("span", { className: "btn red ", onClick: function (e) { return _this.props.close(); } }, "\u5173\u95ED"))))));
    };
    CreateProject.propTypes = {
        onCreatedProject: PropTypes.func,
    };
    return CreateProject;
}(ActionAgent));
export default CreateProject;

==> uke-admin-web-scaffold-1.2.4.tgz: package/fe-deploy/create-project.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
import React from 'react';
import PropTypes from 'prop-types';
import { Loading, FormLayout, Tabs, Tab, Alert, Steps, GlobalPopover, Radio } from 'ukelli-ui';
import { Call } from 'basic-helper';
import CreateAsset from './create-asset';
import AssetsManager from './assets-manager';
import { createProject, getSShConfig } from './apis';
import wrapProjectFormOptions from './project-form';
import ActionAgent from "../action-agent";
var CreateProject = /** @class */ (function (_super) {
    __extends(CreateProject, _super);
    function CreateProject(props) {
        var _this = _super.call(this, props) || this;
        _this.state = __assign(__assign({}, _this.state), { activeIdx: 0, querying: true, createdProj: {} });
        _this.onCreateProj = function (formValue, actingRef) { return __awaiter(_this, void 0, void 0, function () {
            var _a, notify, onCreatedProject, agentOptions;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        _a = this.props, notify = _a.notify, onCreatedProject = _a.onCreatedProject;
                        agentOptions = {
                            actingRef: actingRef,
                            after: function (res) {
                                var err = res.err;
                                if (!err) {
                                    Call(onCreatedProject);
                                }
                                else {
                                    notify('创建项目', false, err);
                                }
                                return err ? {} : {
                                    activeIdx: 1,
                                    createdProj: res.data || {}
                                };
                            }
                        };
                        return [4 /*yield*/, this.reqAgent(createProject, agentOptions)(formValue)];
                    case 1:
                        _b.sent();
                        return [2 /*return*/];
                }
            });
        }); };
        _this.formBtns = [
            {
                action: function (formRef, actingRef) {
                    var checkRes = formRef.checkForm();
                    if (checkRes.isPass)
                        _this.onCreateProj(formRef.value, actingRef);
                },
                actingRef: 'creating',
                text: '新增',
            }
        ];
        return _this;
    }
    CreateProject.prototype.componentDidMount = function () {
        this.initData();
    };
    CreateProject.prototype.initData = function () {
        return __awaiter(this, void 0, void 0, function () {
            var _a, hostConfigRes;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        _a = this;
                        return [4 /*yield*/, wrapProjectFormOptions()];
                    case 1:
                        _a.formOptions = _b.sent();
                        return [4 /*yield*/, getSShConfig()];
                    case 2:
                        hostConfigRes = ((_b.sent()) || {}).data;
                        // let hostConfigData = {};
                        // hostConfigRes.forEach(item => hostConfigData[item.sshHost] = item);
                        this.setState({
                            sshConfig: hostConfigRes,
                            querying: false
                        });
                        return [2 /*return*/];
                }
            });
        });
    };
    // async getSSHConfig() {
    //   let hostConfigRes = await getSShConfig();
    //   // console.log(hostConfigRes)
    // }
    CreateProject.prototype.onCreatedAsset = function (assetData) {
        this.setState({
            activeIdx: 2,
            prevAssetData: assetData
        });
    };
    CreateProject.prototype.render = function () {
        var _this = this;
        var _a = this.state, activeIdx = _a.activeIdx, createdProj = _a.createdProj, querying = _a.querying, sshConfig = _a.sshConfig;
        return (React.createElement("div", null,
            React.createElement(Alert, { title: "\u4F7F\u7528\u8BF4\u660E", texts: [
                    '新建项目，只需要填写项目名称',
                    'web hook 是项目资源发布成功后触发的，与 GitHub 的 web hook 类似，用于回调通知',
                ] }),
            React.createElement(Loading, { loading: querying },
                React.createElement("div", null,
                    React.createElement(Steps, { activeIdx: activeIdx, className: "p10" },
                        React.createElement(Steps.Step, { title: "\u521B\u5EFA\u9879\u76EE" }),
                        React.createElement(Steps.Step, { title: "\u4E0A\u4F20\u8D44\u6E90\u6587\u4EF6" }),
                        React.createElement(Steps.Step, { title: "\u8D44\u6E90\u7BA1\u7406" })),
                    React.createElement(Tabs, { activeTabIdx: activeIdx },
                        React.createElement(Tab, { label: "\u521B\u5EFA\u9879\u76EE" },
                            React.createElement(FormLayout, { formOptions: this.formOptions, ref: function (e) {
                                    if (!e)
                                        return;
                                    _this.formRef = e.formHelper;
                                }, onChange: function (values, ref, val) {
                                    var targetDOM = '';
                                    if (ref !== 'scpTargetHost')
                                        return;
                                    try {
                                        targetDOM = _this.formRef._refs.scpTargetDir.iconInput;
                                    }
                                    catch (e) {
                                        console.log(e);
                                    }
                                    var targetValues = __spreadArrays(sshConfig).filter(function (item) { return item.sshHost === val; });
                                    var ideaTip = {};
                                    for (var _i = 0, targetValues_1 = targetValues; _i < targetValues_1.length; _i++) {
                                        var item = targetValues_1[_i];
                                        ideaTip[item.deployPath] = item.desc + "~" + item.deployPath;
                                    }
                                    var hasIdea = targetValues.length > 0;
                                    if (hasIdea) {
                                        GlobalPopover.show({
                                            elem: targetDOM,
                                            props: {
                                                style: {
                                                    zIndex: 1111,
                                                    width: 400,
                                                }
                                            },
                                            children: (React.createElement("div", { className: "p10" },
                                                React.createElement("h4", null, "\u90E8\u7F72\u8DEF\u5F84\u5EFA\u8BAE"),
                                                React.createElement("div", { className: "p10" },
                                                    React.createElement(Radio, { values: ideaTip, onChange: function (val) { return _this.selectedDeploy = val; } })),
                                                React.createElement("span", { className: "btn theme", onClick: function (e) {
                                                        GlobalPopover.close();
                                                        _this.formRef.changeValues({
                                                            scpTargetDir: _this.selectedDeploy
                                                        });
                                                    } }, "\u786E\u5B9A")))
                                        });
                                    }
                                    // let targetPath = '';
                                    // if(sshConfig[val]) {
                                    //   targetPath = sshConfig[val].deployPath || '';
                                    // }
                                    // this.formRef.changeValues({
                                    //   scpTargetDir: targetPath
                                    // });
                                }, formBtns: this.formBtns })),
                        React.createElement(Tab, { label: "\u4E0A\u4F20\u8D44\u6E90\u6587\u4EF6" },
                            React.createElement(CreateAsset, __assign({}, this.props, { projId: createdProj.id, onSuccess: function (assetData) { return _this.onCreatedAsset(assetData); } }))),
                        React.createElement(Tab, { label: "\u8D44\u6E90\u7BA1\u7406" },
                            React.createElement(AssetsManager, __assign({ releasable: true, getProject: function (e) { return createdProj; } }, this.props, { projId: createdProj.id })))),
                    React.createElement("hr", null),
                    React.createElement("div", { className: "p10 text-center" },
                        React.createElement("span", { className: "btn red ", onClick: function (e) { return _this.props.close(); } }, "\u5173\u95ED"))))));
    };
    CreateProject.propTypes = {
        onCreatedProject: PropTypes.func,
    };
    return CreateProject;
}(ActionAgent));
export default CreateProject;
